@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"path"
 	"path/filepath"
 	"strings"
 
@@ -16,6 +15,8 @@ import (
 	"github.com/spf13/afero"
 	"github.com/tidwall/gjson"
 
+	"github.com/stripe/stripe-cli/pkg/git"
+	"github.com/stripe/stripe-cli/pkg/parsers"
 	"github.com/stripe/stripe-cli/pkg/requests"
 )
 
@@ -46,14 +47,6 @@ type FixtureRequest struct {
 	Context           string                 `json:"context,omitempty"`
 }
 
-// FixtureQuery describes the query in fixture request
-type FixtureQuery struct {
-	Match        string // The substring that matched the query pattern regex
-	Name         string
-	Query        string
-	DefaultValue string
-}
-
 // Fixture contains a mapping of an individual fixtures responses for querying
 type Fixture struct {
 	Fs            afero.Fs
@@ -69,12 +62,11 @@ type Fixture struct {
 }
 
 // NewFixtureFromFile creates a to later run steps for populating test data
-func NewFixtureFromFile(fs afero.Fs, apiKey, stripeAccount, baseURL, file string, skip, override, add, remove []string) (*Fixture, error) {
+func NewFixtureFromFile(fs afero.Fs, apiKey, stripeAccount, baseURL, file string, skip, override, add, remove []string, edit bool) (*Fixture, error) {
 	fxt := Fixture{
 		Fs:            fs,
 		APIKey:        apiKey,
 		StripeAccount: stripeAccount,
-		Skip:          skip,
 		BaseURL:       baseURL,
 		Responses:     make(map[string]gjson.Result),
 	}
@@ -99,20 +91,35 @@ func NewFixtureFromFile(fs afero.Fs, apiKey, stripeAccount, baseURL, file string
 		}
 	}
 
+	// Customize fixture data
+
+	if edit {
+		filedata, err = fxt.Edit(file, filedata)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	err = json.Unmarshal(filedata, &fxt.FixtureData)
 	if err != nil {
 		return nil, err
 	}
 
-	// Customize fixture data
-	if err := fxt.Override(override); err != nil {
-		return nil, err
-	}
-	if err := fxt.Add(add); err != nil {
-		return nil, err
-	}
-	if err := fxt.Remove(remove); err != nil {
-		return nil, err
+	if len(override) > 0 || len(add) > 0 || len(remove) > 0 || len(skip) > 0 {
+		if edit {
+			fmt.Println("Warning: --edit cannot be used with --add, --remove, --override, or --skip. Skipping those flags...")
+		} else {
+			if err := fxt.Override(override); err != nil {
+				return nil, err
+			}
+			if err := fxt.Add(add); err != nil {
+				return nil, err
+			}
+			if err := fxt.Remove(remove); err != nil {
+				return nil, err
+			}
+			fxt.Skip = skip
+		}
 	}
 
 	if fxt.FixtureData.Meta.Version > SupportedVersions {
@@ -255,6 +262,29 @@ func (fxt *Fixture) Remove(removals []string) error {
 	return nil
 }
 
+// Edit opens the fixture in the git's default IDE to edit directly
+func (fxt *Fixture) Edit(path string, filedata []byte) ([]byte, error) {
+	return Edit(path, filedata)
+}
+
+// Edit is separated into a var so we can mock this in fixtures_test
+var Edit = func(path string, filedata []byte) ([]byte, error) {
+	filename := getFixtureFilenameWithWildcard(path)
+	editor, err := git.NewTemporaryFileEditor(filename, filedata)
+	if err != nil {
+		return nil, err
+	}
+
+	return editor.EditContent()
+}
+
+func getFixtureFilenameWithWildcard(path string) string {
+	pathComponents := strings.Split(path, "/")
+	fixtureName := strings.Split(pathComponents[len(pathComponents)-1], ".")
+	// Add a wildcard that is replaced by a random string when passing this filename to os.CreateTemp
+	return strings.Join(fixtureName[0:len(fixtureName)-1], ".") + ".*." + fixtureName[len(fixtureName)-1]
+}
+
 // Execute takes the parsed fixture file and runs through all the requests
 // defined to populate the user's account
 func (fxt *Fixture) Execute(ctx context.Context, apiVersion string) ([]string, error) {
@@ -303,7 +333,7 @@ func (fxt *Fixture) makeRequest(ctx context.Context, data FixtureRequest, apiVer
 		APIBaseURL:     fxt.BaseURL,
 	}
 
-	path, err := fxt.ParsePath(data)
+	path, err := parsers.ParsePath(data.Path, fxt.Responses)
 
 	if err != nil {
 		return make([]byte, 0), err
@@ -315,7 +345,7 @@ func (fxt *Fixture) makeRequest(ctx context.Context, data FixtureRequest, apiVer
 	}
 
 	if data.IdempotencyKey != "" {
-		idempotencyKey, err := fxt.ParseQuery(data.IdempotencyKey)
+		idempotencyKey, err := parsers.ParseQuery(data.IdempotencyKey, fxt.Responses)
 		if err != nil {
 			return nil, fmt.Errorf("error parsing idempotency_key field: %w", err)
 		}
@@ -327,7 +357,7 @@ func (fxt *Fixture) makeRequest(ctx context.Context, data FixtureRequest, apiVer
 
 func (fxt *Fixture) createParams(params interface{}, apiVersion string) (*requests.RequestParameters, error) {
 	requestParams := requests.RequestParameters{}
-	parsed, err := fxt.ParseInterface(params)
+	parsed, err := parsers.ParseInterface(params, fxt.Responses)
 	if err != nil {
 		return &requestParams, err
 	}
@@ -342,30 +372,6 @@ func (fxt *Fixture) createParams(params interface{}, apiVersion string) (*reques
 	return &requestParams, nil
 }
 
-func getEnvVar(query FixtureQuery) (string, error) {
-	key := query.Query
-	// Check if env variable is present
-	envValue := os.Getenv(key)
-	if envValue == "" {
-		// Try to load from .env file
-		dir, err := os.Getwd()
-		if err != nil {
-			dir = ""
-		}
-		err = godotenv.Load(path.Join(dir, ".env"))
-		if err != nil {
-			return "", nil
-		}
-		envValue = os.Getenv(key)
-	}
-	if envValue == "" {
-		fmt.Printf("No value for env var: %s\n", key)
-		return "", nil
-	}
-
-	return envValue, nil
-}
-
 func (fxt *Fixture) updateEnv(env map[string]string) error {
 	dir, err := os.Getwd()
 	if err != nil {
@@ -391,7 +397,7 @@ func (fxt *Fixture) updateEnv(env map[string]string) error {
 	}
 
 	for key, value := range env {
-		parsed, err := fxt.ParseQuery(value)
+		parsed, err := parsers.ParseQuery(value, fxt.Responses)
 		if err != nil {
 			return err
 		}
