@@ -3,15 +3,18 @@ package rpcservice
 import (
 	"context"
 
-	"github.com/stripe/stripe-cli/pkg/login"
+	"github.com/spf13/afero"
+
+	"github.com/stripe/stripe-cli/pkg/config"
+	"github.com/stripe/stripe-cli/pkg/login/keys"
 	"github.com/stripe/stripe-cli/rpc"
 
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
 
-var pollForKey = login.PollForKey
-var configureProfile = login.ConfigureProfile
+var pollForKey = keys.PollForKey
+var configureProfile = saveLoginDetails
 
 // LoginStatus returns when login is successful, or returns an error if failure or timeout.
 func (srv *RPCService) LoginStatus(ctx context.Context, req *rpc.LoginStatusRequest) (*rpc.LoginStatusResponse, error) {
@@ -37,3 +40,8 @@ func (srv *RPCService) LoginStatus(ctx context.Context, req *rpc.LoginStatusRequ
 		AccountId:   accountID,
 	}, nil
 }
+
+func saveLoginDetails(config *config.Config, response *keys.PollAPIKeyResponse) error {
+	configurer := keys.NewRAKConfigurer(config, afero.NewOsFs())
+	return configurer.SaveLoginDetails(response)
+}
